@@ -547,9 +547,9 @@ def download_original_file(client: SoundCloud, track: BasicTrack, title: str, pl
     return (filename, False)
 
 
-def get_track_m3u8(client: SoundCloud, track: BasicTrack, transcoding: Transcoding, **kwargs):
+def get_transcoding_m3u8(client: SoundCloud, transcoding: Transcoding, **kwargs):
     url = transcoding.url
-    bitrate_KBps = 256 / 8 if transcoding.preset == "aac_hq" else 128 / 8
+    bitrate_KBps = 256 / 8 if "aac" in transcoding.preset else 128 / 8
     total_bytes = bitrate_KBps * transcoding.duration
     
     min_size = kwargs.get("min_size") or 0
@@ -574,17 +574,25 @@ def download_hls(client: SoundCloud, track: BasicTrack, title: str, playlist_inf
     
     logger.debug(f"Trancodings: {track.media.transcodings}")
     
-    transcodings = {t.preset: t for t in track.media.transcodings if t.format.protocol == "hls"}
-    transcoding = None
+    aac_transcoding = None
+    mp3_transcoding = None
+    
+    for t in track.media.transcodings:
+        if t.format.protocol == "hls" and "aac" in t.preset:
+            aac_transcoding = t
+        elif t.format.protocol == "hls" and "mp3" in t.preset:
+            mp3_transcoding = t
+    
     aac = False
-    if not kwargs.get("onlymp3") and "aac_hq" in transcodings:
-        transcoding = transcodings["aac_hq"]
+    transcoding = None
+    if not kwargs.get("onlymp3") and aac_transcoding:
+        transcoding = aac_transcoding
         aac = True
-    elif "mp3_0_0" in transcodings:
-        transcoding = transcodings["mp3_0_0"]
+    elif mp3_transcoding:
+        transcoding = mp3_transcoding
                 
     if not transcoding:
-        raise SoundCloudException(f"Could not find mp3_0_0 or aac_hq transcoding. Available transcodings: {list(transcodings)}")
+        raise SoundCloudException(f"Could not find mp3 or aac transcoding. Available transcodings: {[t.preset for t in track.media.transcodings if t.format.protocol == 'hls']}")
 
     filename = get_filename(track, None, aac, playlist_info, **kwargs)
     logger.debug(f"filename : {filename}")
@@ -593,7 +601,7 @@ def download_hls(client: SoundCloud, track: BasicTrack, title: str, playlist_inf
         return (filename, True)
 
     # Get the requests stream
-    url = get_track_m3u8(client, track, transcoding, **kwargs)
+    url = get_transcoding_m3u8(client, transcoding, **kwargs)
     filename_path = os.path.abspath(filename)
 
     p = subprocess.Popen(
